/*  gtail
 *  Copyright (C) 1999 Didier Remy
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

/*
 * $Log: session.c,v $
 * Revision 1.2  1999/12/30 09:01:04  didier
 * Internationalisation
 *
 * Revision 1.1  1999/12/21 18:22:44  didier
 * Initial revision
 *
 *
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include "support.h" /* pour intl */
#include "file.h"
#include "option.h"
const char session_file[] = ".gtail.session";

extern void AddNoteBookPage(void *, char *, int);
extern void *findNB();

#include <stdio.h>
#include <stdlib.h> /* getenv */
#include <unistd.h> /* getcwd */
#include <errno.h>

#if 0
/* return a string (free it) containing the path to the session file
 * TODO: a fonction to test/create the $HOME/.gtail directory
 */
char *
path2session_file()
{
  char *p;
  int l;

  if (SFHOME == options[which_opt].session_file)
    p = getenv("HOME");
  else
  {
    l = 128;
    p = (char *)malloc(l);
    while (getcwd(p, l) == NULL && errno == ERANGE && l < 65535)
    {
      l += 128;
      p = (char *)realloc(p, l);
    }
    if (l >= 65535)
    {
      free(p);
      p = NULL;
      fprintf(stderr, _("current working directory path name is too long (limited to 65535 characters)\n"));
    }
  }
  if (p)
  {
    p = (char *)realloc(p, strlen(p) + 10);
    if ('/' != p[strlen(p) - 1])
      strcat(p, "/");
    strcat(p, ".gtail/");
  }

  return p;
}
#endif

void
save_session()
{
  FILE * f;
  int ind = 0;

  if (xfi)
  {
    f = fopen(session_file, "w");
    if (f)
    {
      fprintf(f, _("# An gtail session file\n# Format : as many line as you need\n# - beginning with a # means it is a comment\n# - beginning with a %c means open a command (ex.: %cwget www.gdk.org)\n# - anything else not empty is assumed to be a file\n\n"), options[which_opt].character_for_pipe, options[which_opt].character_for_pipe);
      while (xfi[ind].has_changed != LAST && xfi[ind].has_changed != UNUSED)
      {
	switch(xfi[ind].has_changed)
	{
	case IS_DEAD:
	case IS_DEADNCHANGED:
	  fprintf(f, "%c", options[which_opt].character_for_pipe);
	case CHANGED:
	case NOT_CHANGED:
	  fprintf(f, "%s\n", xfi[ind].filename);
	}
	ind++;
      }
      fprintf(f, _("# END\n"));
      fclose(f);
    }
    else
    {
      perror(_("save_session:opening for write fail"));
    }
  }
}

void
load_session()
{
  FILE * f;
  char buf[1024];

  f = fopen(session_file, "r");
  if (f)
  {
    while (!feof(f))
    {
      fgets(buf, 1024, f);
      switch (buf[0])
      {
      case '\n':
      case '#':
	break;
      default:
	buf[strlen(buf) - 1] = '\0';
	if (buf[0] == options[which_opt].character_for_pipe)
	  AddNoteBookPage(findNB(), &buf[1], 1);
	else
	  AddNoteBookPage(findNB(), buf, 0);
      }
    }
    fclose(f);
  }
}
